MEG Examples
------------

This directory contains example scripts for training dynamic network models on MEG data.

The `projects` directory contains example scripts for specific datasets. The other directories are generic pipelines.

The most popular pipelines use the TDE-HMM to compare groups using resting-state data (see **tde-hmm_rest**) or to study an evoked response to a task (see **tde-hmm_task**).
